@@ -41,7 +41,7 @@ def readJson(dataFile, jsonFile):
         dataDF = caps(dataDF, json_file['caps'])
 
     # ** QUOTES ***
-    #dataDF = dataCleaning.quotes(dataDF, json_file['str_quotation'])
+    # dataDF = dataCleaning.quotes(dataDF, json_file['str_quotation'])
 
     # -----------------------------------------------------
 
@@ -53,15 +53,19 @@ def readJson(dataFile, jsonFile):
     # OverSampling
     if json_file['balance_data'] == "yes":
         dataDF = oversampling(dataDF, json_file['balance_params']['balance_method'],
-                                           json_file['balance_params']['y_col'])
+                              json_file['balance_params']['y_col'])
         dataDF.drop(columns=dataDF.columns[0], axis=1, inplace=True)
 
     # -----------------------------------------------------
 
     # PRESENTATION
 
-    # Stats
-    showStats(original_dataDF, dataDF)
+    # Summary
+    summary(json_file)
 
-    #dataDF = dataDF.drop(columns=dataDF.columns[0], axis=1, inplace=True)
-    writeDF(dataDF, json_file['new_file_route'], json_file['new_fileName'], json_file['output_format'], json_file['index'])
+    # Stats
+    showStats(original_dataDF, dataDF, json_file, json_file['balance_params']["y_col"])
+
+    # dataDF = dataDF.drop(columns=dataDF.columns[0], axis=1, inplace=True)
+    writeDF(dataDF, json_file['new_file_route'], json_file['new_fileName'], json_file['output_format'],
+            json_file['index'])
