@@ -12,8 +12,7 @@ def checkJSONFormat(json_file, cols, col_types):
     accepted_balanceData = ["yes", "no"]
     accepted_normalize = ["max_abs", "min_max", "z_score", "no"]
     accepted_balanceMethod = ["random", "smote"]
-    accepted_index = ["true", "false"]
-    # accepted_quotation = ["double", "single", "none"]
+    accepted_index = ["True", "False"]
 
     if json_file['input_format'] not in accepted_inputForm:
         print("ERROR in JSON: input_format is not an accepted value")
